Summary: Secure Sockets Layer communications libs & utils
Name: openssl
%define majorver 0.9.7
Version: %{majorver}c
Release: 3tr
License: BSD-like
Group: Environment/Cryptography
%define m2crypto_version 0.09
%define swig_version 1.3.17
Source: http://www.openssl.org/source/openssl-%{version}.tar.gz
Source1: http://download.sourceforge.net/swig/swig-%{swig_version}.tar.gz
Source2: m2crypto-%{m2crypto_version}.tar.gz
Patch1: openssl-0.9.7-m2crypto-0.09-types.patch
Patch2: openssl-0.9.7-perl.patch
Patch3: openssl-0.9.7-man.patch
Patch4: openssl-0.9.7-include.patch
Patch5: openssl-0.9.7c-CAN-2004-0079.patch
Patch6: openssl-0.9.7c-CAN-2004-0112.patch
Provides: SSL libssl.so libssl.so.0 libcrypto.so.0
URL: http://www.openssl.org
BuildRoot: /var/tmp/openssl-%{version}-root
BuildRequires: python-devel, perl, zlib-devel

%description
A C library that provides various crytographic algorithms and protocols,
including DES, RC4, RSA, and SSL. Includes shared libraries.

%package support
Summary: Secure Sockets Layer communications support utilities.
Group: Environment/Cryptography
Requires: openssl = %{version}, perl
%description support
A C library that provides various crytographic algorithms and protocols,
including DES, RC4, RSA, and SSL. Includes support utilities.

%package devel
Summary: Secure Sockets Layer communications static libs & headers.
Group: Libraries/Development
Requires: openssl = %{version}
%description devel
A C library that provides various crytographic algorithms and protocols,
including DES, RC4, RSA, and SSL. Includes static libraries and headers.

%package python
Summary: Support for using OpenSSL in python scripts.
Group: Libraries/Runtime
Requires: python, openssl = %{version}
%description python
This package allows you to call OpenSSL functions from python scripts.

%prep
%setup -q
%setup -q -T -D -n openssl-%{version}

perl util/perlpath.pl /usr/bin

perl -p -i -e "s/-m486/-march=%_target_cpu/" Configure

# Extract what we need for building extensions.
gzip -dc %{SOURCE1} | tar xf -
gzip -dc %{SOURCE2} | tar xf -
pushd m2crypto-%{m2crypto_version}
    for file in demo/evp_ciph_test.py demo/bio_ciph_test.py swig/_evp.i ; do
	grep -v idea_ ${file} > ${file}.tmp
	grep -v rc5_  ${file}.tmp > ${file}
    done
popd

%patch1 -p1
#%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1


%build
PATH=${PATH}:${PWD}/bin
TOPDIR=${PWD}
export LD_LIBRARY_PATH=`pwd`
RPM_OPT_FLAGS="$RPM_OPT_FLAGS"
export RPM_OPT_FLAGS
./config --prefix=/usr --openssldir=/etc/ssl shared threads zlib zlib-dynamic
make
make do_linux-shared
make rehash
make test

## Build shared libraries.
majorver=`echo %{version} | cut -f1 -d.`
for shlib in crypto ssl ; do
	pushd $shlib
		objs=`ar t ../lib${shlib}.a | xargs -n 1 find . -name`
		%{__cc} -shared -o ../lib${shlib}.so.%{version} \
			-Wl,-soname=lib${shlib}.so.${majorver} $objs && \
		ln -sf lib${shlib}.so.%{version} ../lib${shlib}.so
	popd
done

# Build a copy of swig with which to build the extensions.
pushd SWIG-%{swig_version}
autoconf
CFLAGS="%{optflags}" \
CCFLAGS="%{optflags}" \
FFLAGS="%{optflags}" \
./configure --prefix=${TOPDIR}
make 
make install
popd

# Build the python extensions.
pushd m2crypto-%{m2crypto_version}/swig
export PATH=`pwd`/../../bin/:$PATH
make -f Makefile.py21\
	INCLUDE="-I. -I../../include -I../.." \
	LIBS="-L${TOPDIR} -lssl -lcrypto -lc" \
	PYINCLUDE="-DHAVE_CONFIG_H -I/usr/include/python2.2 -I/usr/lib/python2.2/config" \
	PYLIB="/usr/lib/python2.2/config"
popd

	
%install
[ -n "$RPM_BUILD_ROOT" -a "$RPM_BUILD_ROOT" != / ] && rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/usr/share/man
mkdir -p $RPM_BUILD_ROOT/etc/ssl
mkdir -p $RPM_BUILD_ROOT/usr/bin
mkdir -p $RPM_BUILD_ROOT/usr/include/openssl
mkdir -p $RPM_BUILD_ROOT/usr/lib
make INSTALL_PREFIX=$RPM_BUILD_ROOT install
mv $RPM_BUILD_ROOT/etc/ssl/misc/* $RPM_BUILD_ROOT/usr/bin
rm -rf $RPM_BUILD_ROOT/etc/ssl/misc
rm -rf $RPM_BUILD_ROOT/etc/ssl/lib

install -m644 libcrypto.a $RPM_BUILD_ROOT/usr/lib
install -m644 libssl.a $RPM_BUILD_ROOT/usr/lib

strip $RPM_BUILD_ROOT/usr/bin/openssl

# Install the python extensions.
pushd m2crypto-%{m2crypto_version}/M2Crypto
mkdir -p $RPM_BUILD_ROOT/usr/lib/python2.2/site-packages/M2Crypto/{PGP,SSL}
install -m644 *.py $RPM_BUILD_ROOT/usr/lib/python2.2/site-packages/M2Crypto/
install -m755 *.so $RPM_BUILD_ROOT/usr/lib/python2.2/site-packages/M2Crypto/
python -c "import compileall; compileall.compile_dir('"$RPM_BUILD_ROOT/usr/lib/python2.2/site-packages/M2Crypto"', 3, '/usr/lib/python2.2/site-packages/M2Crypto')"
popd

mv $RPM_BUILD_ROOT/etc/ssl/man/* $RPM_BUILD_ROOT/usr/share/man/
mv $RPM_BUILD_ROOT/usr/share/man/man1/passwd.1 \
	$RPM_BUILD_ROOT/usr/share/man/man1/passwd_openssl.1
rm $RPM_BUILD_ROOT/usr/share/man/man3/MD5.3


%post -p /sbin/ldconfig


%postun -p /sbin/ldconfig


%clean
[ -n "$RPM_BUILD_ROOT" -a "$RPM_BUILD_ROOT" != / ] && rm -rf $RPM_BUILD_ROOT


%files
%defattr(-,root,root)
%doc CHANGES CHANGES.SSLeay INSTALL LICENSE README NEWS
#%doc doc/*
/usr/bin/openssl
/usr/lib/libcrypto.so.0
/usr/lib/libcrypto.so.%{majorver}
/usr/lib/libssl.so.0
/usr/lib/libssl.so.%{majorver}
%config(noreplace) %verify(not md5 size mtime) /etc/ssl/openssl.cnf
%dir /etc/ssl
%dir /etc/ssl/private
%dir /etc/ssl/certs
/usr/share/man/man1/*

%files support
%defattr(-,root,root)
/usr/bin/CA.pl
/usr/bin/CA.sh
/usr/bin/c_hash
/usr/bin/c_info
/usr/bin/c_issuer
/usr/bin/c_name
#/usr/bin/der_chop
/usr/bin/c_rehash
		
%files devel
%defattr(-,root,root)
/usr/lib/libcrypto.a
/usr/lib/libssl.a
/usr/lib/libcrypto.so
/usr/lib/libssl.so
/usr/include/openssl
/usr/share/man/man3/*
/usr/share/man/man5/*
/usr/share/man/man7/*
 
%files python
%defattr(-,root,root)
%doc m2crypto-%{m2crypto_version}/{BUGS,CHANGES,LIC*,README,TODO}
%{_libdir}/python2.2/site-packages/M2Crypto


%changelog
* Tue Sep 28 2004 Oystein Viggen <oysteivi at trustix dot com> 0.9.6-18tr
- Remove der_chop (has a security hole, and according to openssl developers
  shouldn't be used anyway).

* Tue Mar 16 2004 Oystein Viggen <oysteivi at trustix dot com> 0.9.7c-2tr
- Patch two potential DoS attack holes: CAN-2004-0079, CAN-2004-0112

* Tue Sep 30 2003 Chr. Toldnes <christht at tawie dot org> 0.9.7c-1tsl
- upstream security fixes

* Mon Jun 23 2003 Erlend Midttun <erlendbm at trustix dot com> 0.9.7b-3tr
- Added %defattr.

* Wed Jun 18 2003 Erlend Midttun <erlendbm at trustix dot com> 0.9.7b-2tr
- Big rebuild

* Fri May 23 2003 Erlend Midttun <erlendbm at trustix dot com> 0.9.7b-1em
- New upstream.

* Mon Mar 24 2003 Erlend Midttun <erlendbm at trustix dot com> 0.9.7a-4em
- Rebuilt against glibc 2.3.2.

* Thu Mar 20 2003 Erlend Midttun <erlendbm at trustix dot com> 0.9.7a-3em
- Apply patch against the blinding attack known as CAN-2003-0147
- Apply patch against the Klima-Pokorny-Rose attack. CAN-2003-131

* Thu Feb 27 2003 Erlend Midttun <erlendbm at trustix dot com> 0.9.7a-2em
- Make setup quiet.

* Thu Feb 20 2003 Christian H. Toldnes <christht at trustix dot org> 0.9.7a-1ct
- Upstream securityfix
- move *.so to devel
- finally openssl seems backwards compatible between 0.9.7 and 0.9.7{a-z}

* Thu Feb 13 2003 Erlend Midttun <erlendbm at trustix dot com> 0.9.7-3em
- Fix include of non-exported file e_os.h

* Wed Jan 29 2003 Goetz Bock <bock at trustix dot org> 0.9.7-2bg
- added patch to use perl from /usr/bin/perl (patch2)
- renamed passwd to passwd_openssl (patch3), as shadow-utils 
  provides passwd
- removed MD5.3 manpage, as it conflicts with perl
- removed doc/* from %doc, as all the files are included as man pages

* Thu Jan 16 2003 Gerald Dachs <gda at trustix dot org> 0.9.7-1gd
- new upstream version (bug 16)
- swig 1.3.17
- m2crypto 0.09
- changed target cpu
- rsaref disappeared, removed files
- changed types for python extension (Patch 1)
- removed c++ patch

* Tue Dec 24 2002 Gerald Dachs <gda at trustix dot org> 0.9.6h-1gd
- new upstream version

* Wed Sep 18 2002 Roland Kruse <rolandk at trustix dot com> 0.9.6g-3rk
- Small patch to make des.h usable with C++ (Patch0)

* Fri Sep 13 2002 Erlend Midttun <erlendbm at trustix dot com>
- Added BuildReq python-devel
- Changed include to remove -I.../openssl

* Mon Aug 12 2002 Christian H. Toldnes <christht at trustix dot com> 0.9.6g-1ct
- New upstream version fixes many security issues.

* Wed Jul 10 2002 Christian H. Toldnes <christht at trustix dot com> 0.9.6d-2ct
- Added Provides: libssl.so, libssl.so.0, ect <-- ugly, must fix this later.
- License: BSD-like

* Fri May 31 2002 Christian H. Toldnes <christht at trustix dot com>
- Update: openssl-0.9.6d, swig-1.3.6, m2crypto_0.07-snap3

* Wed Jul 11 2001 Oystein Viggen <oysteivi at trustix dot com>
- Patch a security hole in the prng

* Mon Jun 25 2001 Oystein Viggen <oysteivi at trustix dot com>
- Split off a -support package to remove perl dependancy from main package

* Thu Jun  7 2001 Erlend Midttun <erlendbm at trustix dot com>
- Added a few patches to fix a few issues with 0.9.6.  Would upgrade
  to 0.9.6a, but that seem to break a load of packages.  Patches are
  from Engarde, not sure where they got them.

* Wed Mar  7 2001 Alexander Reelsen <ar at trustix dot com>
- Moved libssl.so files completely out of openssl-devel

* Fri Feb 9 2001 Olaf Trygve Berglihn <olafb at trustix dot com>
- Added openssl-python - the python M2Crypto bindings.

* Wed Nov 22 2000 Erlend Midttun <erlendbm at trustix dot com>
- Updated to 0.9.6

* Mon Sep 4 2000 Per Ivar Paulsen <perp at trustix dot com>
- Fixed man bug. openssl.cnf path fix.

* Thu May 18 2000 Erlend Midttun <erlendbm at trustix dot com>
- Updated to version 0.9.5a

* Thu Mar 02 2000 Lars Gaarden <larsg at trustix dot com>
- moved openssl.cnf back to /etc/ssl

* Thu Feb  3 2000 Tore Olsen <toreo at trustix dot com>
- updated to 0.9.4

* Thu Jun 3 1999 Greg LaPolla <glapolla@hotmail.com>
- Added shared lib copy stuff 
* Tue Jun 1 1999 Greg LaPolla <glapolla@hotmail.com>
- Created SPEC and patches specific to rh6  

